@@ -10,6 +10,7 @@ use Lingua::FreeLing3::Bindings;
 use Lingua::FreeLing3::Sentence;
 use Lingua::FreeLing3::ChartParser;
 use Lingua::FreeLing3::DepTree;
+use Scalar::Util 'blessed';
 
 use parent -norequire, 'Lingua::FreeLing3::Bindings::dep_txala';
 
@@ -41,10 +42,40 @@ Object constructor. One argument is required: the languge code
 files) or the full or relative path to the dependencies file together
 with the full or relative path to the chart parser data file.
 
+=over 4
+
+=item C<ChartParser>
+
+Specify a reference to a L<Lingua::FreeLing3::ChartParser> where the
+grammar start symbol should be obtained.
+
+=item C<StartSymbol>
+
+If you do not have the C<ChartParser> but know what is the grammar
+start symbol, pass it with this option.
+
+=back
+
 =cut
 
 sub new {
-    my ($class, $lang, $chartParser) = @_;
+    my ($class, $lang, %ops) = @_;
+
+    my $start_symbol;
+
+    if (exists($ops{ChartParser}) &&
+        blessed($ops{ChartParser}) &&
+        $ops{ChartParser}->isa('Lingua::FreeLing3::Bindings::chart_parser')) {
+        $start_symbol = $ops{ChartParser}->start_symbol();
+    }
+    elsif (exists($ops{StartSymbol})) {
+        $start_symbol = $ops{StartSymbol};
+    }
+    else {
+        my $chartParser = Lingua::FreeLing3::ChartParser->new($lang);
+        $chartParser or die "Cannot guess what chart parser to use";
+        $start_symbol = $chartParser->start_symbol();
+    }
 
     my $dep_txala_file;
     if ($lang =~ /^[a-z]{2}$/i) {
@@ -62,17 +93,20 @@ sub new {
         return undef;
     }
 
-    unless (ref($chartParser) && $chartParser->isa('Lingua::FreeLing3::Bindings::chart_parser')) {
-        carp "Supplied chart parser is not a chart parser\n";
-        return undef;
-    }
-
     my $self = Lingua::FreeLing3::Bindings::dep_txala->new($dep_txala_file,
-                                                           $chartParser->start_symbol);
+                                                           $start_symbol);
     return bless $self => $class #amen
 }
 
 
+=head2 C<parse>
+
+Alias to C<analyze>.
+
+=cut
+
+sub parse { &analyze }
+
 =head2 C<analyze>
 
 Receives a list of sentences, and returns that same list of sentences
