@@ -61,7 +61,7 @@ sub new {
 =head2 C<analyze>
 
 Receives a list of sentences, and returns that same list of sentences
-after...
+with classified entities.
 
 =cut
 
